# -*- coding: utf-8 -*-
"""
Anonymize the second evaluation round of the Dutch translation.

2023-06-17
"""

import pandas as pd
import pyreadstat  # for writing .sav-files


def anonymize(df_q, df_p, id_extension):
    """
    Anonymize the Qualtrics and Prolific data.
    Creates a new random ID called "rand_id".

    Parameters
    ----------
    df_q : dataframe
        Qualtrics data.
    df_p : dataframe
        Prolific data.
    id_extension : string
        Extension to add to new random IDs.

    Returns
    -------
    df_q : dataframe
        Anonymized Qualtrics data.
    df_p : dataframe
        Anonymized Prolific data.

    """

    # Only use qualtrics data of people who passed in prolific
    df_q = df_q[df_q["PROL_ID_C"].isin(df_p["Participant id"].to_list())]

    # Remove columns we cannot publish from Qualtrics data
    df_q = df_q.drop(["StartDate", "EndDate", "Status", "Progress", 
                      "Duration__in_seconds_", "RecordedDate", "ResponseId", 
                      "DistributionChannel", "UserLanguage",
                      "PIV_E_G_Fluency_1", "PIV_E_G_Fluency_2", 
                      "PIV_E_G_Fluency_3", "PIV_E_G_Fluency_9",
                      "PIV_E_G_Fluency_5", "PIV_E_G_Fluency_10", 
                      "PIV_E_G_Fluency_8", "agentName", "SESSION_ID",
                      "STUDY_ID", "Consent2", "PROLIFIC_PID",
                      "TIME_VID_INTRO_First_Click", "TIME_VID_INTRO_Last_Click",
                      "TIME_VID_INTRO_Page_Submit", "TIME_VID_INTRO_Click_Count"], 
                     axis = 1)
    
    # One person did the questionnaire twice (first time stopped after informed consent)
    # So we remove this unfinished entry from this person.
    df_q = df_q[df_q["Finished"] == "True"]

    # Ceate new random ID
    prolific_ids_sorted = sorted(df_q["PROL_ID_C"].to_list())
    df_q["rand_id"] = ["P" + str(prolific_ids_sorted.index(df_q.iloc[i]["PROL_ID_C"]) + 1) + id_extension for i in range(len(df_q))]
    df_p["rand_id"] = ["P" + str(prolific_ids_sorted.index(df_p.iloc[i]["Participant id"]) + 1) + id_extension for i in range(len(df_p))]

    # Drop original ID columns
    df_q = df_q.drop(["PROL_ID_C"], axis = 1)
    df_p = df_p.drop(["Participant id"], axis = 1)

    return df_q, df_p


if __name__ == "__main__":

    # Load data
    df_q = pd.read_spss("Qualtrics_Exports/Round_2/Final_ASA_Dutch_round2_2023_06_17.sav")
    df_p_m = pd.read_excel("Prolific_Exports/Round_2/prolific_export_dutch_round_2_male_nonbinary_2023_06_17.xlsx")
    df_p_f = pd.read_excel("Prolific_Exports/Round_2/prolific_export_dutch_round_2_female_2023_06_17.xlsx")

    # Merge male and female Prolific data
    df_p = pd.concat([df_p_m, df_p_f])

    # Anonymize
    df_q, df_p = anonymize(df_q, df_p, "_R2")

    # Save anonymized dataframes
    df_p.to_csv("Prolific_Exports/Round_2/prolific_export_dutch_round2_anonym.csv",
                index=False)
    pyreadstat.write_sav(df_q, "Qualtrics_Exports/Round_2/Final_ASA_Dutch_Round_2_anonym.sav")
